<p align="center"> <img src="src/scramble_generator/resources/images/scramble_generator_with_text-256.png" /> </p>

## Donations

- [Buy Me A Coffee](https://www.buymeacoffee.com/KingKairos)
- [GitHub Sponsors](https://github.com/sponsors/melvinquick)

## Purpose

The general purpose of this app is to give people an easy way to generate scrambles for standard twisty puzzles.

## App Showcase

![app_showcase.gif](scramblegenerator/src/scramblegenerator/resources/gifs/app_showcase.gif)

## Useful Information

- [Project Goals](https://codeberg.org/melvinquick/scramble_generator/projects/11195)
- [Latest Release](https://codeberg.org/melvinquick/scramble_generator/releases/latest)
- [Releases](https://codeberg.org/melvinquick/scramble_generator/releases)
